summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/spinbox2.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/spinbox2.h')
-rw-r--r--kalarm/lib/spinbox2.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kalarm/lib/spinbox2.h b/kalarm/lib/spinbox2.h
index f83db252..4391fbb9 100644
--- a/kalarm/lib/spinbox2.h
+++ b/kalarm/lib/spinbox2.h
@@ -59,20 +59,20 @@ class SpinBox2 : public TQFrame
TQ_OBJECT
public:
/** Constructor.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit SpinBox2(TQWidget* tqparent = 0, const char* name = 0);
+ explicit SpinBox2(TQWidget* parent = 0, const char* name = 0);
/** Constructor.
* @param minValue The minimum value which the spin box can have.
* @param maxValue The maximum value which the spin box can have.
* @param step The (unshifted) step interval for the right-hand spin buttons.
* @param step2 The (unshifted) step interval for the left-hand spin buttons.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
SpinBox2(int minValue, int maxValue, int step = 1, int step2 = 1,
- TQWidget* tqparent = 0, const char* name = 0);
+ TQWidget* parent = 0, const char* name = 0);
/** Sets whether the spin box can be changed by the user.
* @param readOnly True to set the widget read-only, false to set it read-write.
*/
@@ -282,10 +282,10 @@ class SpinBox2 : public TQFrame
class MainSpinBox : public SpinBox
{
public:
- MainSpinBox(SpinBox2* sb2, TQWidget* tqparent, const char* name = 0)
- : SpinBox(tqparent, name), owner(sb2) { }
- MainSpinBox(int minValue, int maxValue, int step, SpinBox2* sb2, TQWidget* tqparent, const char* name = 0)
- : SpinBox(minValue, maxValue, step, tqparent, name), owner(sb2) { }
+ MainSpinBox(SpinBox2* sb2, TQWidget* parent, const char* name = 0)
+ : SpinBox(parent, name), owner(sb2) { }
+ MainSpinBox(int minValue, int maxValue, int step, SpinBox2* sb2, TQWidget* parent, const char* name = 0)
+ : SpinBox(minValue, maxValue, step, parent, name), owner(sb2) { }
void tqsetAlignment(int a) { editor()->tqsetAlignment(a); }
virtual TQString mapValueToText(int v) { return owner->mapValueToText(v); }
virtual int mapTextToValue(bool* ok) { return owner->mapTextToValue(ok); }
@@ -59,20 +59,20 @@ class SpinBox2 : public TQFrame
public:
/** Constructor.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -59,20 +59,20 @@ class SpinBox2 : public TQFrame
* @param step The (unshifted) step interval for the right-hand spin buttons.
* @param step2 The (unshifted) step interval for the left-hand spin buttons.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/